==> gottet_1.1.9.orig.tar.gz: gottet-1.1.9/translations/gottet_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Τέλος του τρέχοντος παιχνιδιού;</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt; Παύση&lt;/ b&gt;&lt;/ big&gt;&lt;br&gt;Κάντε κλικ για να συνεχίσετε το παιχνίδι.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt; Το παιχνίδι τελείωσε!&lt;/ b&gt;&lt;/big&gt;&lt;br&gt;Κάντε κλικ για να ξεκινήσετε ένα νέο παιχνίδι.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Επιλέξτε την γλώσσα εφαρμογής:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Γλώσσα συστήματος&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Σημείωση</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Παρακαλούμε κάντε επανεκκίνηση αυτής της εφαρμογής για να τεθεί σε ισχύ η αλλαγή της γλώσσας.</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>Gottet Βαθμολογία</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Επίπεδο</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Γραμμές</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Βαθμολογία</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Κάντε κλικ για να ξεκινήσετε ένα νέο παιχνίδι.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Παιχνίδι</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Νεο</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Παύση</translation>
    </message>
    <message>
        <source>P</source>
        <translation>Π</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Συνέχεια</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Βαθμολογίες</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Έξοδος</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Γλώσσα &amp;εφαρμογής...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Σχετικά </translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Σχετικά με το &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Επόμενο κομμάτι</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Επίπεδο</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Κατάργηση γραμμών</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Βαθμολογία</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>Ένας κλώνος του tetris που έκανα για τη γυναίκα μου</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Πνευματική ιδιοκτησία &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Διατίθεται βάσει της &lt;a href=%1&gt;GPL 3&lt;/a&gt; άδειας χρήσης</translation>
    </message>
</context>
</TS>

==> gottet_1.2.4.orig.tar.gz: gottet-1.2.4/translations/gottet_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Τέλος του τρέχοντος παιχνιδιού;</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt; Παύση&lt;/ b&gt;&lt;/ big&gt;&lt;br&gt;Κάντε κλικ για να συνεχίσετε το παιχνίδι.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt; Το παιχνίδι τελείωσε!&lt;/ b&gt;&lt;/big&gt;&lt;br&gt;Κάντε κλικ για να ξεκινήσετε ένα νέο παιχνίδι.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Επιλέξτε την γλώσσα εφαρμογής:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Γλώσσα συστήματος&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Σημείωση</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Παρακαλούμε κάντε επανεκκίνηση αυτής της εφαρμογής για να τεθεί σε ισχύ η αλλαγή της γλώσσας.</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>Επίπεδο</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Γραμμές</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Βαθμολογία</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Κάντε κλικ για να ξεκινήσετε ένα νέο παιχνίδι.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Παιχνίδι</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Νεο</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Παύση</translation>
    </message>
    <message>
        <source>P</source>
        <translation>Π</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Βαθμολογίες</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Έξοδος</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Γλώσσα &amp;εφαρμογής...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Σχετικά </translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Σχετικά με το &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Επόμενο κομμάτι</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Επίπεδο</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Κατάργηση γραμμών</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Βαθμολογία</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Πνευματική ιδιοκτησία &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Διατίθεται βάσει της &lt;a href=%1&gt;GPL 3&lt;/a&gt; άδειας χρήσης</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
